==> uxkit-0.0.2.tgz: package/built/UXKit/TabBarController.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { Control } from "./Control";
import { PixelLine } from "./PixelLine";
import { ImageView } from "./ImageView";
import { Label } from "./Label";
import { Font } from "./Font";
import { ViewController } from "./ViewController";
import { ControlEvents } from "./Enum";
import { PresetColor } from "./Types";
/**
 * TabBar
 */
export class TabBar extends View {
    itemView(item, idx) {
        let color = this.props.selectedIndex === idx ? this.props.tintColor : PresetColor.secondTextColor;
        return (React.createElement(RN.View, {key: "item_" + idx, style: { flex: 1, height: this.props.frame.height, justifyContent: "center" }}, React.createElement(RN.View, {style: { flexDirection: "column", alignItems: "center", alignSelf: "center" }}, React.createElement(ImageView, {image: item.image, tintColor: color, margin: { bottom: 2 }}), React.createElement(Label, {text: item.title, font: Font.fontWithSize(12), textColor: color, margin: { top: 2 }}))));
    }
    view() {
        let items = this.props.items.map((item, idx) => {
            return this.itemView(item, idx);
        });
        return (React.createElement(RN.View, {style: { flex: 1 }}, React.createElement(PixelLine, {frame: { height: 1 }}), React.createElement(RN.View, {style: { flexDirection: "row" }}, items)));
    }
}
TabBar.defaultProps = Object.assign({}, View.defaultProps, {
    frame: { x: 0, mx: 0, my: 0, height: 50 },
    backgroundColor: "#f8f8f8",
    items: [],
    selectedIndex: 0,
});
/**
 * TouchableTabBar
 */
class TouchableTabBar extends View {
    itemView(item, idx) {
        let color = this.props.selectedIndex === idx ? this.props.tintColor : PresetColor.secondTextColor;
        return (React.createElement(Control, {backTouchingArea: 0, key: "item_" + idx, style: { flex: 1, height: this.props.frame.height }, moveAllow: 44.0, handler: (event) => {
            if (event == ControlEvents.TouchUpInside) {
                this.props.handler && this.props.handler(idx);
            }
        }}));
    }
    view() {
        let items = this.props.items.map((item, idx) => {
            return this.itemView(item, idx);
        });
        return (React.createElement(RN.View, {style: { flex: 1 }}, React.createElement(PixelLine, {frame: { height: 1 }, color: "#ffffff00"}), React.createElement(RN.View, {style: { flexDirection: "row" }}, items)));
    }
}
TouchableTabBar.defaultProps = Object.assign({}, View.defaultProps, {
    backgroundColor: "#ffffff00",
    items: [],
    selectedIndex: 0,
});
/**
 * TabBarController
 */
export class TabBarController extends ViewController {
    constructor(props) {
        super(props);
        this.viewControllers = [];
        this.tabItems = [];
        this.state = Object.assign({}, this.state, {
            selectedIndex: 0,
            hiddingWhilePushing: false,
        });
    }
    componentDidMount() {
        super.componentDidMount();
        if (TabBarController.sharedController === undefined) {
            TabBarController.sharedController = this;
        }
    }
    setSelectedIndex(selectedIndex) {
        this.setState({
            selectedIndex: selectedIndex
        });
    }
    tabBar() {
        return (React.createElement(TabBar, {userInteractionEnabled: false, items: this.tabItems, selectedIndex: this.state.selectedIndex}));
    }
    touchableTabBar() {
        return (React.createElement(TouchableTabBar, {frame: this.tabBar().props.frame, userInteractionEnabled: !this.state.hiddingWhilePushing, items: this.tabItems, selectedIndex: this.state.selectedIndex, handler: (selectingIndex) => {
            this.setState({
                selectedIndex: selectingIndex,
            });
        }}));
    }
    loadView() {
        let vcStack = this.viewControllers.map((viewController, idx) => {
            return (React.createElement(RN.View, {key: "vc_" + idx, style: { position: "absolute", top: 0, left: 0, right: 0, bottom: 0, overflow: 'visible', opacity: idx === this.state.selectedIndex ? 1.0 : 0.0 }, pointerEvents: idx === this.state.selectedIndex ? "box-none" : "none"}, viewController, this.state.selectedIndex === idx ? this.touchableTabBar() : null));
        });
        return (React.createElement(View, {style: { flex: 1 }}, this.tabBar(), vcStack));
    }
}
TabBarController.sharedController = undefined;

==> uxkit-0.0.3.tgz: package/built/UXKit/TabBarController.js <==
/// <reference path="../../typings/tsd.d.ts"/>
import * as React from "react";
import * as RN from "react-native";
import { View } from "./View";
import { Control } from "./Control";
import { PixelLine } from "./PixelLine";
import { ImageView } from "./ImageView";
import { Label } from "./Label";
import { Font } from "./Font";
import { ViewController } from "./ViewController";
import { ControlEvents } from "./Enum";
import { PresetColor } from "./Types";
/**
 * TabBar
 */
export class TabBar extends View {
    itemView(item, idx) {
        let color = this.props.selectedIndex === idx ? this.props.tintColor : PresetColor.secondTextColor;
        return (React.createElement(RN.View, {key: "item_" + idx, style: { flex: 1, height: this.props.frame.height, justifyContent: "center" }}, React.createElement(RN.View, {style: { flexDirection: "column", alignItems: "center", alignSelf: "center" }}, React.createElement(ImageView, {image: item.image, tintColor: color, margin: { bottom: 2 }}), React.createElement(Label, {text: item.title, font: Font.fontWithSize(12), textColor: color, margin: { top: 2 }}))));
    }
    view() {
        let items = this.props.items.map((item, idx) => {
            return this.itemView(item, idx);
        });
        return (React.createElement(RN.View, {style: { flex: 1 }}, React.createElement(PixelLine, {bottom: 0}), React.createElement(RN.View, {style: { flexDirection: "row" }}, items)));
    }
}
TabBar.defaultProps = Object.assign({}, View.defaultProps, {
    frame: { x: 0, mx: 0, my: 0, height: 50 },
    backgroundColor: "#f8f8f8",
    items: [],
    selectedIndex: 0,
});
/**
 * TouchableTabBar
 */
class TouchableTabBar extends View {
    itemView(item, idx) {
        let color = this.props.selectedIndex === idx ? this.props.tintColor : PresetColor.secondTextColor;
        return (React.createElement(Control, {backTouchingArea: 0, key: "item_" + idx, style: { flex: 1, height: this.props.frame.height }, moveAllow: 44.0, handler: (event) => {
            if (event == ControlEvents.TouchUpInside) {
                this.props.handler && this.props.handler(idx);
            }
        }}));
    }
    view() {
        let items = this.props.items.map((item, idx) => {
            return this.itemView(item, idx);
        });
        return (React.createElement(RN.View, {style: { flex: 1 }}, React.createElement(PixelLine, {bottom: 0, color: "#ffffff00"}), React.createElement(RN.View, {style: { flexDirection: "row" }}, items)));
    }
}
TouchableTabBar.defaultProps = Object.assign({}, View.defaultProps, {
    backgroundColor: "#ffffff00",
    items: [],
    selectedIndex: 0,
});
/**
 * TabBarController
 */
export class TabBarController extends ViewController {
    constructor(props) {
        super(props);
        this.viewControllers = [];
        this.tabItems = [];
        this.state = Object.assign({}, this.state, {
            selectedIndex: 0,
            hiddingWhilePushing: false,
        });
    }
    componentDidMount() {
        super.componentDidMount();
        if (TabBarController.sharedController === undefined) {
            TabBarController.sharedController = this;
        }
    }
    setSelectedIndex(selectedIndex) {
        this.setState({
            selectedIndex: selectedIndex
        });
    }
    tabBar() {
        return (React.createElement(TabBar, {userInteractionEnabled: false, items: this.tabItems, selectedIndex: this.state.selectedIndex}));
    }
    touchableTabBar() {
        return (React.createElement(TouchableTabBar, {frame: this.tabBar().props.frame, userInteractionEnabled: !this.state.hiddingWhilePushing, items: this.tabItems, selectedIndex: this.state.selectedIndex, handler: (selectingIndex) => {
            this.setState({
                selectedIndex: selectingIndex,
            });
        }}));
    }
    loadView() {
        let vcStack = this.viewControllers.map((viewController, idx) => {
            return (React.createElement(RN.View, {key: "vc_" + idx, style: { position: "absolute", top: 0, left: 0, right: 0, bottom: 0, overflow: 'visible', opacity: idx === this.state.selectedIndex ? 1.0 : 0.0 }, pointerEvents: idx === this.state.selectedIndex ? "box-none" : "none"}, viewController, this.state.selectedIndex === idx ? this.touchableTabBar() : null));
        });
        return (React.createElement(View, {style: { flex: 1 }}, this.tabBar(), vcStack));
    }
}
TabBarController.sharedController = undefined;
